#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AERvIDIxIE5vdiAyMDAyIDExOjQ1OjQ1ICswMTAwsqsFmAAAAAd0SU1FB9MIDQ0eFFwnL8wA'
    b'AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAAE/klEQVR42uVWXWxURRQ+'
    b'c+/d7W53a39sMYFWfhYlxWgI+oBNMP48CKLRF/TBhAdfmvjEg4QHnhoTE01MfCPwqkZoiaKJ'
    b'0GqCISDGgFi0QNJWaNmtVLplW7e73fszM56ZO3c7e9vtFlufnPTr/Oydc75zzjd3LsD/vZG1'
    b'Npi9+fnItTOHt3qOB5RS4ByAUReww56CWNjS1d391CsfH1/zaDjnHcNn3+F/jX6NQ4ZwECWE'
    b'p8aMD1/8gF/6dP+vwR5jDZ0TjHjvzNgP0Lr5eVyZQeQRBUQOMSvR/uQ+mB4f7OR8uE7ss2oZ'
    b'vvfLkTN24V49YbzZcwsWprGBOQWLMjfOnHmLOqWI5xXNq8dTZqlUIBBrBMMQtu/r9FTvQvyh'
    b'zWAXMvhALIELdk0Co5c+3Nu+6zCKpQ5idUkwog1gRBqAWEmIRBM4T4KJ8yjaMyJx3CEwjfDA'
    b'lxgNWbSkLgD+hhVlgIMJHc+8r1LKFKjqPW2tpJBTEZMKKwvNUT+tlAALDEyFDAWNVTrC8DhD'
    b'1TMbVe+AWdcEhJjac1bFlpoEKDV81gjGHOBoVBgWPWfz/lw4pCXpFAfokKEOfPJWYiNEkx0q'
    b'I0xlQARSIGUCve9CEhKwwbBgPe7bQLA3DRwjPM+G+dlbYOfPATFMMCwDDBN7MTYJmBYB/MM5'
    b'k5ESTvzSIBHmeVAsjEE00YZOg5KYFcWRBHgSBhsfSaWSD3dAfWMbxBtbUa0tiCYY+uoIxBoa'
    b'cLxJ1Y5J48A91Qu4frjBmiIgSJmkCG7pLkTibWWXTJYgrxEA+H5r14FUatdbSlgi5bYEE4wN'
    b'R61z1a9HMroYqQ+xRhRB4oszWs/AdUwk0KyejULXgRPgvxcCDRD44s7g6e7UrjeI78Atg0un'
    b'84oQh4H0Othzdnct6dRo22D7jdkXcdAnCRi34McsGZwo3L/dnmhp07LgqGMsCIgj9ig6fwmO'
    b'Pb0695+NA1zINvaK0CWBN/uAnjzET2WG+g9ue24/6Flg8uRh9Eyo1y0b6R7I/nsGySS+CGNa'
    b'CUAe31Pp384dfHz3ayhYukBACgZfGryosuJHAK2tqywDVBK4mYCftqeHxwu58Y3JltZyFjgX'
    b'B3oOhwhjXj77yaZBMLYsGBEkdYhbNzwO969P7qgk0NMD7MQh6EtfO/9e5wv7/CMViJChYine'
    b'atyWz+7cuWNRJIFxATz+FX14LACT/r6K69gg0JcZ+hlvVoxUgBbxRCEBimfWRQK0tCZpr/Cp'
    b'T65/BFdymfFMMZtBynMSUoRuzs8A+48J9IhMcn564vfL6DQvCcgSUBShhyJkdlVD3L+HVkdA'
    b'NI/Bl+nrQ+UMUFECb8afVylBIDhBQH32VUW4LboNR6/ARZNMTNn5bFtdzFRvXyRA58oZEE6I'
    b'dqMEToM+IBOAaddveL4oAz3nwcNvx/67IyOyDEzscEQGFjSgqzk4VkLly2UiTKoqAcmSwrcT'
    b'I3d8DQgVejmfgFcqp1wnoDsPvwdqlWLJDxLiwHd/jmU95uYteQwcIUhaLoFwGBagHnkw1skE'
    b'82C8bAbePgq5UtG9OjM5hfXApwlGbxTBs55YsgR6GZZ6C+oEg9+WJaDSfGHi9jR+VHC4cTkP'
    b'3/TOweTsYyzIwFLQHYfLEqyvSAOqHf1jbJ0djTfPpSc7TxYjTc+2d75qVcuAngk9C9VQLjc8'
    b'aDvGX8b//Q+8b3HbA91kYA3srK79A38+eaaryzPWAAAAAElFTkSuQmCC')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAADYXpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHja7VdZju0oDP1nFb2E2GYwy2GU3g56+X0ckvTNHaT3VPXT6goKEGOOh2O4'
    b'VW78/Wu6v/DwFtX5kDTmGDc8PvvMBRPd1lP2nja/9/vDxxK+b3J3LTBEglHWp8ZD/5TTBbCG'
    b'gll4ANJ2LNT7QvYHvj4BHZbFPLJ5P4DyASS8FugAKCusLWZNjyHUscZ+RqLrddZ5vbv98p2Q'
    b'vR5gR5iHkGzoWXg5IPaSk4IJoWcRXmKTRPRezlCRkHd52h68cs+sXDP6IH8iReKSOwjuyYzX'
    b'+FZO4Ul+ALo9xQ+WpV2Wb/JOl4lbku2ds6ubc6zoio9IaTyCOkPZZ1CsSLns2yJawhswT3vL'
    b'aOpQvQ2U961tFa1RJgYtkzx1KjRp7GOjBhc9D04YmRuIMplK4sxNNgfGvDWanCRLFwVzDfQK'
    b'pHz5QrvdvJtrpDDcCZpMACMrBWfdd7SPQHNayRNteuUKfrEVIdww5qyHFgihedZR2BN8tufH'
    b'eBUwGPY0KwIsW10QNdBRW1ZHshMtUAwY11mj1A8ApAi2A5whAQNbJAkUaUvMiQh5VPBTAKQs'
    b'nisooBC4w0v2IhHkKJtt7Em063LgJcadZccHxyiBmiwFXHlcbKif5BU1VIIEH0KIIQUNOZQo'
    b'0ccQY0zRLr+SJPkUUkwpacqpqKjXoFGTqtOsJXMWXI4hx5yy5pxLgdEC5ILdBQqlVK5SfQ01'
    b'1lS15loayqf5FlpsqalruZXOXTruiR576tpzL4MGSmn4EUYcaejIo0yU2pTpZ5hxpqkzz3Kx'
    b'Rm7R+tJ+nzU6WeOdKVNMF2vYmtIJQXadBOMMjLEnMJ6MARQ0G2ebkvfsjDrjbMu42SQwvAxG'
    b'Dk47GAODfhCHSRd3/zJ34815/yXe+GTOGXXfwZwz6j4w98rbG9a6/dq0TdzOkB1DS+omOH5Q'
    b'GFpYi/2o/fbo/nTDD9AP0P8aqI6J01amrilENtUyq52/8+sdmNtmZVwSU3t8XL5L7asOCZe5'
    b'Vm5r0HRfBTj3u9dgnn1/F5x92d+3S80w3Vo02HP3MnVKL6cW8u7U49qp6b4KcEbkPodk2Hsc'
    b'lo8jks9F4L6jiswT95Lo04s/hHPfUdU/QD9A/yGgib99Mv7H+AcyreZ3cOZYtwAAAYRpQ0NQ'
    b'SUNDIHByb2ZpbGUAAHicfZE9SMNQFIVPU7UiFQc7FHHIUJ0siIo4ahWKUCHUCq06mLz0D5o0'
    b'JCkujoJrwcGfxaqDi7OuDq6CIPgD4ubmpOgiJd6XFFrEeOHxPs675/DefYDQqDDN6hoHNN02'
    b'08mEmM2tiqFXBBCFgB6EZGYZc5KUgm993VM31V2cZ/n3/Vn9at5iQEAknmWGaRNvEE9v2gbn'
    b'feIIK8kq8TnxmEkXJH7kuuLxG+eiywLPjJiZ9DxxhFgsdrDSwaxkasRTxDFV0ylfyHqsct7i'
    b'rFVqrHVP/sJwXl9Z5jqtYSSxiCVIEKGghjIqsBGnXSfFQprOEz7+IdcvkUshVxmMHAuoQoPs'
    b'+sH/4PdsrcLkhJcUTgDdL47zMQKEdoFm3XG+jx2neQIEn4Erve2vNoCZT9LrbS12BAxsAxfX'
    b'bU3ZAy53gOiTIZuyKwVpCYUC8H5G35QDBm+BvjVvbq1znD4AGZpV6gY4OARGi5S97vPu3s65'
    b'/dvTmt8P0MtyZm2C+RoAAA+gaVRYdFhNTDpjb20uYWRvYmUueG1wAAAAAAA8P3hwYWNrZXQg'
    b'YmVnaW49Iu+7vyIgaWQ9Ilc1TTBNcENlaGlIenJlU3pOVGN6a2M5ZCI/Pgo8eDp4bXBtZXRh'
    b'IHhtbG5zOng9ImFkb2JlOm5zOm1ldGEvIiB4OnhtcHRrPSJYTVAgQ29yZSA0LjQuMC1FeGl2'
    b'MiI+CiA8cmRmOlJERiB4bWxuczpyZGY9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkvMDIvMjIt'
    b'cmRmLXN5bnRheC1ucyMiPgogIDxyZGY6RGVzY3JpcHRpb24gcmRmOmFib3V0PSIiCiAgICB4'
    b'bWxuczppcHRjRXh0PSJodHRwOi8vaXB0Yy5vcmcvc3RkL0lwdGM0eG1wRXh0LzIwMDgtMDIt'
    b'MjkvIgogICAgeG1sbnM6eG1wTU09Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9tbS8i'
    b'CiAgICB4bWxuczpzdEV2dD0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL3NUeXBlL1Jl'
    b'c291cmNlRXZlbnQjIgogICAgeG1sbnM6cGx1cz0iaHR0cDovL25zLnVzZXBsdXMub3JnL2xk'
    b'Zi94bXAvMS4wLyIKICAgIHhtbG5zOkdJTVA9Imh0dHA6Ly93d3cuZ2ltcC5vcmcveG1wLyIK'
    b'ICAgIHhtbG5zOmRjPSJodHRwOi8vcHVybC5vcmcvZGMvZWxlbWVudHMvMS4xLyIKICAgIHht'
    b'bG5zOnRpZmY9Imh0dHA6Ly9ucy5hZG9iZS5jb20vdGlmZi8xLjAvIgogICAgeG1sbnM6eG1w'
    b'PSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIgogICB4bXBNTTpEb2N1bWVudElEPSJn'
    b'aW1wOmRvY2lkOmdpbXA6MGM3NGZmZDQtMTNiMS00NjZiLThhNGYtOTE4ZjVlMjlhMWY5Igog'
    b'ICB4bXBNTTpJbnN0YW5jZUlEPSJ4bXAuaWlkOjA5YzI3ZDI3LWVkNzgtNGQwMC05NzYwLWNk'
    b'NWYwZjMwNDI1YSIKICAgeG1wTU06T3JpZ2luYWxEb2N1bWVudElEPSJ4bXAuZGlkOmUyZjM1'
    b'NWMxLTc3OTQtNDk5MC05NTBiLTNkM2U0MGQyNmQ1ZCIKICAgR0lNUDpBUEk9IjIuMCIKICAg'
    b'R0lNUDpQbGF0Zm9ybT0iTWFjIE9TIgogICBHSU1QOlRpbWVTdGFtcD0iMTYxMTQ1NDAwNzg4'
    b'ODE4MSIKICAgR0lNUDpWZXJzaW9uPSIyLjEwLjIyIgogICBkYzpGb3JtYXQ9ImltYWdlL3Bu'
    b'ZyIKICAgdGlmZjpPcmllbnRhdGlvbj0iMSIKICAgeG1wOkNyZWF0b3JUb29sPSJHSU1QIDIu'
    b'MTAiPgogICA8aXB0Y0V4dDpMb2NhdGlvbkNyZWF0ZWQ+CiAgICA8cmRmOkJhZy8+CiAgIDwv'
    b'aXB0Y0V4dDpMb2NhdGlvbkNyZWF0ZWQ+CiAgIDxpcHRjRXh0OkxvY2F0aW9uU2hvd24+CiAg'
    b'ICA8cmRmOkJhZy8+CiAgIDwvaXB0Y0V4dDpMb2NhdGlvblNob3duPgogICA8aXB0Y0V4dDpB'
    b'cnR3b3JrT3JPYmplY3Q+CiAgICA8cmRmOkJhZy8+CiAgIDwvaXB0Y0V4dDpBcnR3b3JrT3JP'
    b'YmplY3Q+CiAgIDxpcHRjRXh0OlJlZ2lzdHJ5SWQ+CiAgICA8cmRmOkJhZy8+CiAgIDwvaXB0'
    b'Y0V4dDpSZWdpc3RyeUlkPgogICA8eG1wTU06SGlzdG9yeT4KICAgIDxyZGY6U2VxPgogICAg'
    b'IDxyZGY6bGkKICAgICAgc3RFdnQ6YWN0aW9uPSJzYXZlZCIKICAgICAgc3RFdnQ6Y2hhbmdl'
    b'ZD0iLyIKICAgICAgc3RFdnQ6aW5zdGFuY2VJRD0ieG1wLmlpZDoyNjUwN2FkNS03MGI4LTQ1'
    b'YzItYWYzYy04NWYyZmNmODhhODEiCiAgICAgIHN0RXZ0OnNvZnR3YXJlQWdlbnQ9IkdpbXAg'
    b'Mi4xMCAoTWFjIE9TKSIKICAgICAgc3RFdnQ6d2hlbj0iMjAyMS0wMS0yM1QyMDowNjo0Ny0w'
    b'NjowMCIvPgogICAgPC9yZGY6U2VxPgogICA8L3htcE1NOkhpc3Rvcnk+CiAgIDxwbHVzOklt'
    b'YWdlU3VwcGxpZXI+CiAgICA8cmRmOlNlcS8+CiAgIDwvcGx1czpJbWFnZVN1cHBsaWVyPgog'
    b'ICA8cGx1czpJbWFnZUNyZWF0b3I+CiAgICA8cmRmOlNlcS8+CiAgIDwvcGx1czpJbWFnZUNy'
    b'ZWF0b3I+CiAgIDxwbHVzOkNvcHlyaWdodE93bmVyPgogICAgPHJkZjpTZXEvPgogICA8L3Bs'
    b'dXM6Q29weXJpZ2h0T3duZXI+CiAgIDxwbHVzOkxpY2Vuc29yPgogICAgPHJkZjpTZXEvPgog'
    b'ICA8L3BsdXM6TGljZW5zb3I+CiAgPC9yZGY6RGVzY3JpcHRpb24+CiA8L3JkZjpSREY+Cjwv'
    b'eDp4bXBtZXRhPgogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'IAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAK'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgCjw/eHBhY2tldCBlbmQ9InciPz68Mg6lAAAABmJLR0QA/wD/AP+gvaeTAAAACXBI'
    b'WXMAAAsTAAALEwEAmpwYAAAAB3RJTUUH5QEYAgYv3J844AAAAHFJREFUWMPtlEsKACEMQxPx'
    b'TN5/3UvVldCBcRDxM4u8XYNgSD+AEEKIffjIIx4y0P0nbU6BwYzfboG/GaGZOQCUUggArV6g'
    b'9aJ/tIZB4EfvZrSRGfN0e1WymcXI0OpV2ux2HBvCfHgb+LtDdP0UCyGEqMGXOgXDiP2LAAAA'
    b'AElFTkSuQmCC')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAADKXpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHja7ZZbktwgDEX/WUWWYEkIxHJ4VmUHWX4u+JF2T0/VJJPPNmXAAkmgI2O7'
    b'/uvncD9w8Sab8xotpBA2XD75xBkd2/Yrr5o2v+p18TGE55vcXQMMkaCV/dHCMf+U02VgbzJ6'
    b'+mDI6jFQ7gPJH/btydDhWeaKZr8dhtJhSHgfoMNA3re1hWTxcQul7207d2L77Wbl7b7sD88R'
    b'0WsKP8LchWRDzcL7AmTe5CSjQ6hZhHdxFnRRk4TDGALyKk7bw6rcM5WrR5/In6DA2ZI7CO7B'
    b'DFf7Uk76JD8MuhXiB89SL883ea6Xi1uQ5z1GMzdG33eXfUBIw7Gpcyurh4kFIZelFlAibkU/'
    b'rpJQzCF7K5C3rW4FpVIiBpZBnhplGtRXW6liiZ47R7TMFaCmzCRy4opXBGz8LDQ4SpImBmIV'
    b'eAVSvtZCy29a7ioZHDfCTCYYo5kKblb/o3xqaIyZ8kSbXbHCungmIZYxyc0aswCExplHugJ8'
    b'ludrchUQ1BVmwwbzVnYTRenIrZlHskALJira/V2j2A4DCBF8KxZDAgJbIFEKtEXmSIQ4Gvhk'
    b'GDIWzwUISJUbVsleJACO8fQNnUhrLivvYpxZAKESJAJNkgxWHgcb8id6Qw5lFfWqGjSqadIc'
    b'JPigIYQY5uGXo0QfNYYYo8UUs4l5UwsWzZwly4mT4HDUFFJMllLKGU4zLGdoZ0zIuXCR4ouW'
    b'UGKxkkquSJ/qq9ZQYzVXU82NmzScEy202Kylljt1pFL3XXvosVtPPQ+k2pDhh44w4rCRRr6o'
    b'kduxfihfp0YnNV6k5sR4UYNqjKcJmseJTmYgxp5APE4CSGiezDYj79lNdJPZlnCyiTJWqRNO'
    b'o0kMBH0n1kEXuz/kbtyc99/ixic5N9H9D3JuovuE3EduL6i1+bWpm7hFaL6GM6ib4PXDhG6Z'
    b'Lc+P2pdb97cKb0NvQ29Df9WOMt9MfCCH3YZLHwPdXTonzX/G16p3TffvqndN91p1tbv+Pu9h'
    b'dOpj/ik/DOD/6N+VH3Xdd5QfW/d98G9Db0NvQ98wNPDDktxvZnzLvr7XBjQAAAGEaUNDUElD'
    b'QyBwcm9maWxlAAB4nH2RPUjDUBSFT1NFkYqgHYoIZqhOFkRFHLUKRagQaoVWHUxe+gdNGpIU'
    b'F0fBteDgz2LVwcVZVwdXQRD8AXFzc1J0kRLvSwotYrzweB/n3XN47z5AqJeZZnWMA5pum6lE'
    b'XMxkV8WuVwQQgYBh9MvMMuYkKQnf+rqnbqq7GM/y7/uzetWcxYCASDzLDNMm3iCe3rQNzvvE'
    b'YVaUVeJz4jGTLkj8yHXF4zfOBZcFnhk206l54jCxWGhjpY1Z0dSIp4ijqqZTvpDxWOW8xVkr'
    b'V1nznvyFoZy+ssx1WkNIYBFLkCBCQRUllGEjRrtOioUUncd9/IOuXyKXQq4SGDkWUIEG2fWD'
    b'/8Hv2Vr5yQkvKRQHOl8c52ME6NoFGjXH+T52nMYJEHwGrvSWv1IHZj5Jr7W06BHQtw1cXLc0'
    b'ZQ+43AEiT4Zsyq4UpCXk88D7GX1TFhi4BXrWvLk1z3H6AKRpVskb4OAQGC1Q9rrPu7vb5/Zv'
    b'T3N+PyqgcooyZuksAAAPoGlUWHRYTUw6Y29tLmFkb2JlLnhtcAAAAAAAPD94cGFja2V0IGJl'
    b'Z2luPSLvu78iIGlkPSJXNU0wTXBDZWhpSHpyZVN6TlRjemtjOWQiPz4KPHg6eG1wbWV0YSB4'
    b'bWxuczp4PSJhZG9iZTpuczptZXRhLyIgeDp4bXB0az0iWE1QIENvcmUgNC40LjAtRXhpdjIi'
    b'PgogPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJk'
    b'Zi1zeW50YXgtbnMjIj4KICA8cmRmOkRlc2NyaXB0aW9uIHJkZjphYm91dD0iIgogICAgeG1s'
    b'bnM6aXB0Y0V4dD0iaHR0cDovL2lwdGMub3JnL3N0ZC9JcHRjNHhtcEV4dC8yMDA4LTAyLTI5'
    b'LyIKICAgIHhtbG5zOnhtcE1NPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvbW0vIgog'
    b'ICAgeG1sbnM6c3RFdnQ9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNv'
    b'dXJjZUV2ZW50IyIKICAgIHhtbG5zOnBsdXM9Imh0dHA6Ly9ucy51c2VwbHVzLm9yZy9sZGYv'
    b'eG1wLzEuMC8iCiAgICB4bWxuczpHSU1QPSJodHRwOi8vd3d3LmdpbXAub3JnL3htcC8iCiAg'
    b'ICB4bWxuczpkYz0iaHR0cDovL3B1cmwub3JnL2RjL2VsZW1lbnRzLzEuMS8iCiAgICB4bWxu'
    b'czp0aWZmPSJodHRwOi8vbnMuYWRvYmUuY29tL3RpZmYvMS4wLyIKICAgIHhtbG5zOnhtcD0i'
    b'aHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wLyIKICAgeG1wTU06RG9jdW1lbnRJRD0iZ2lt'
    b'cDpkb2NpZDpnaW1wOjA1OWU2NTBjLTYxNzctNDc4NC1iODIzLWEzZTM2NmM0YjFhNyIKICAg'
    b'eG1wTU06SW5zdGFuY2VJRD0ieG1wLmlpZDo5MTU3YTY0NS05Mjc4LTQxMTUtYmE2Yy0zZDFi'
    b'YWQ5MmIxMzMiCiAgIHhtcE1NOk9yaWdpbmFsRG9jdW1lbnRJRD0ieG1wLmRpZDozNGJkMzFl'
    b'NC00NGY4LTQxY2MtODAyZS04MDA4ZjY2NjVjMjEiCiAgIEdJTVA6QVBJPSIyLjAiCiAgIEdJ'
    b'TVA6UGxhdGZvcm09Ik1hYyBPUyIKICAgR0lNUDpUaW1lU3RhbXA9IjE2MTE0NTU1NDIyNjIw'
    b'MzciCiAgIEdJTVA6VmVyc2lvbj0iMi4xMC4yMiIKICAgZGM6Rm9ybWF0PSJpbWFnZS9wbmci'
    b'CiAgIHRpZmY6T3JpZW50YXRpb249IjEiCiAgIHhtcDpDcmVhdG9yVG9vbD0iR0lNUCAyLjEw'
    b'Ij4KICAgPGlwdGNFeHQ6TG9jYXRpb25DcmVhdGVkPgogICAgPHJkZjpCYWcvPgogICA8L2lw'
    b'dGNFeHQ6TG9jYXRpb25DcmVhdGVkPgogICA8aXB0Y0V4dDpMb2NhdGlvblNob3duPgogICAg'
    b'PHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9jYXRpb25TaG93bj4KICAgPGlwdGNFeHQ6QXJ0'
    b'd29ya09yT2JqZWN0PgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6QXJ0d29ya09yT2Jq'
    b'ZWN0PgogICA8aXB0Y0V4dDpSZWdpc3RyeUlkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNF'
    b'eHQ6UmVnaXN0cnlJZD4KICAgPHhtcE1NOkhpc3Rvcnk+CiAgICA8cmRmOlNlcT4KICAgICA8'
    b'cmRmOmxpCiAgICAgIHN0RXZ0OmFjdGlvbj0ic2F2ZWQiCiAgICAgIHN0RXZ0OmNoYW5nZWQ9'
    b'Ii8iCiAgICAgIHN0RXZ0Omluc3RhbmNlSUQ9InhtcC5paWQ6MGYxMGNmZGYtOGZhYi00YWZl'
    b'LWFkYTEtZmZiNGEyYTNkMTI3IgogICAgICBzdEV2dDpzb2Z0d2FyZUFnZW50PSJHaW1wIDIu'
    b'MTAgKE1hYyBPUykiCiAgICAgIHN0RXZ0OndoZW49IjIwMjEtMDEtMjNUMjA6MzI6MjItMDY6'
    b'MDAiLz4KICAgIDwvcmRmOlNlcT4KICAgPC94bXBNTTpIaXN0b3J5PgogICA8cGx1czpJbWFn'
    b'ZVN1cHBsaWVyPgogICAgPHJkZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VTdXBwbGllcj4KICAg'
    b'PHBsdXM6SW1hZ2VDcmVhdG9yPgogICAgPHJkZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VDcmVh'
    b'dG9yPgogICA8cGx1czpDb3B5cmlnaHRPd25lcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVz'
    b'OkNvcHlyaWdodE93bmVyPgogICA8cGx1czpMaWNlbnNvcj4KICAgIDxyZGY6U2VxLz4KICAg'
    b'PC9wbHVzOkxpY2Vuc29yPgogIDwvcmRmOkRlc2NyaXB0aW9uPgogPC9yZGY6UkRGPgo8L3g6'
    b'eG1wbWV0YT4KICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'IAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAK'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgIAo8P3hwYWNrZXQgZW5kPSJ3Ij8+Nl3WgwAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlz'
    b'AAALEwAACxMBAJqcGAAAAAd0SU1FB+UBGAIgFkBEM8wAAAAqSURBVFjD7dGhAQAgAALB1/13'
    b'1uoEGrxLQKUAgMdGtY7c0a9s0wcA8L0NctoHAyid3RAAAAAASUVORK5CYII=')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AERpIDE2IEF1ZyAyMDA1IDEzOjU3OjUwICswMTAw0YaYRwAAAAd0SU1FB9MCDg4hMoy3iRsA'
    b'AAAJcEhZcwAACvAAAArwAUKsNJgAAAAEZ0FNQQAAsY8L/GEFAAAHEUlEQVR42sWXe2xT1xnA'
    b'v3Puw49rx5A4cQKhwXKANBntBGx0jJWGUryWxwgdC2VapbF1oElUAiGWP1ijSmuhXbutD22C'
    b'atq0SFuWtJuqKlo3lhIppSFxE0ICSaBJnBckTnBim9j3de49O9eQiFaahmnQPvvzvbqv73e+'
    b'5zXA/1nQfztRU1MjiKJYoWvabqLrX5MVOVfXdUPXyaROyHlVVescDsc/jh07Zi44QGdn55Oj'
    b'IyNvhgcH/LJBZYe3IMm7FxsUIUQSMZyKjLr02bhNp3BZkqSDVVVV5xcMoOvixZ93d3dVh6ei'
    b'yYeCuyK5RUWKTijohokUjSKNIKQYFCdGB6XZjn9nR68N8zandKi6uvqdewHgvrDyqo5PQ79I'
    b'uXMmK3747MzS7EW8C5s2CQwbpgyCECC3FTmydBpYl3TxIEQHLj/92ObHB5ubm7vuGaCjvX1D'
    b'X0/PnxJS9tSOp3fKmJicDVGBo5QDjCkA5djCKTEoJRaMbiDTIKB7i2WvgxfGei/sfOQbG+pb'
    b'W1unMwHg53ZmZmZe649ElYrnv39T1wxxMYecDoxFBZla/pvcUmAIYDBlKVezLdJHkQjWMURk'
    b'dNP/reiK0nBhT9eFE+yK72YCgK2fhoaG9Vd7Lz+yYvO2CNIM3gZIYGS8yawJFiQz+vpz++DV'
    b'5yrTEOPhAVFTZExZBhnMIxKnY+GhLTGBQ985cOBAUcYA8VisIq4QzfNAQAGTIsM0YUY3Zc2g'
    b'pmqA9WGGjHTsgX3lVBKxpAST1QWLBogcQhHBl/L7/VhR5O0Zh0CW5bXcYl9KZikug0F5Exur'
    b'fi8um3O5pZZxC8Lar778hB+6b4Xk5W+P9Lt5FxIxB1LhCs3o6l6TMQCjzsc5PkJUE8WoSTBg'
    b'ZD38lz/ZmzZqMo9YW0tf+PG2+Up49XQjTIyGxUXFAXaDRO2ePEI0vSBjAINlM7Amo5kmknWT'
    b'jumaaq10zuicUuZvckcpWuFIpZJYQJSjJiKY49KwGQNomn7dTCaW6TpCcZ3VnZUZ7OFVv62f'
    b'z/zjP3oybfTk6TO3js0pa4+sWvBNhQKdvSEQw7ieMYBOjBCaHn9MNpgXDEJFjNDvgtevTo4M'
    b'8qqcwi/3bl0+v2od4ID/vTEQ7FQ3EfJluQXNBKSwU8lrAwLCuC0TgHQVCILwd5KMCXJkyKkQ'
    b'hJPsiQYvQlZBkZHrX0Wslc4DsH3E26nkKzJ8/hKz9MFiNK6K+vpc6jzX0kKYMxoyBjh69Gg7'
    b'4sVm2v2RVwE7UnRAKguHyTvBFFzUCsdrp87Cb043pwE0tnLB5sQPF2aLSWo3IypHoeefWdFY'
    b'4v36+vprmQDMD6MTJ06sScxEW3zrtqTi/o1RjijWYRZYNoBY3d8YGxKUVAoR5m6vR+IeLlmJ'
    b'Vc5mtkdMfV/+tPfkz35q92R74x6P5weFhYW7ZpPJX71y8mTP/wKYnwWNjY3jT2wNTieGe3fl'
    b'ue1czFmkIqCYJQnzKockdxbKy8vFxYX5nDfHi67JnBFOYGOvb8b7+vHnHU9t34nKysrsbrf7'
    b'mYJlD6wZHxsmn7Sc//CuASxpamoKbXx0U2zyysWnlvNxEWfl4SnTRUzM6oITkEYFiGg2Y1Th'
    b'jNU5gq0s+rHr1y+94CjfshXt378feJ6H0rLVqKO1GbaffWP1qUVa64sRCN9VCO6UI0eOfDMR'
    b'j73llhyrileWaPYlJaqQ41N4xJucHBXUsV7bR01NYmQqeklyuReXl5eXBgIBCAaDUFv7Z3hw'
    b'6BQUJBLgujQqO8eju9Gn8GFGAHMJevDgwS2s7+8mRF9HdJJnsubPZsB11o9CNputjsnHlZWV'
    b'+cx43549lZ6+/n4oMepgZS4GZyQBMMwmc3u/AuGp76F2+CBTgLuSw4cP7y0pLf1LIqXC12+8'
    b'C2sfXQJSnoc1BRVgaApg9AaDGFBhYHIfg/jbF+/n78Xo59yE8dm+8EjdpnN/LF9e5sh1jNgA'
    b'JKYOpstzrRZvKZvwuJZyE8+iNqhdUA/MCS2FsqhXaszZGPBBgM2jVUwlO5t0rHUO3/ZER5hA'
    b'//h+FIKaufu4L2P0TnlxCqZe8ekNEJ2tAJvoZu8VAFkOACfzhNt+a62SDYOS3FH+lfWiK7gn'
    b'2tbySeRLh+Bz7myDXvrV5GZo++wMa2DsfYJNsZKlt0DS4SBwyXic78zeftw92PcMu6UYLyRA'
    b'GqITrsDN1GYIXR2GgQmAvjH2ypUCYI6IFa6FyQ3HILDESzVN+4N1/YIDpCFC0A/TCvNE/xB8'
    b'ZkGMwuQYhtiyQ1C2sgjaQyGIx+Pn7hvAbU8MgqpsgrYrA9G+GJyZDQKPNKj7a601fa3kl+4r'
    b'QBqiBUZAJsG3XTuoJInwzulTlK0cJiYmmp1O57/S19xPAEteeuNtHBkePMv+4GiJROIQx3Eu'
    b'tr1QW1tr3G/bdyX/AXbykwAPX4syAAAAAElFTkSuQmCC')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAABhGlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kT1Iw1AUhU9TRZGKiB1EHDJUJwtFRTpqFYpQIdQKrTqYvPQPmjQkKS6OgmvBwZ/FqoOL'
    b's64OroIg+APi5uak6CIl3pcUWsR44fE+zrvn8N59gNCoMM3qigGabpvpZELM5lbFnlcEMAgg'
    b'hrjMLGNOklLwra976qa6i/Is/74/q1/NWwwIiMSzzDBt4g3imU3b4LxPHGYlWSU+J54w6YLE'
    b'j1xXPH7jXHRZ4JlhM5OeJw4Ti8UOVjqYlUyNeJo4omo65QtZj1XOW5y1So217slfGMrrK8tc'
    b'pzWKJBaxBAkiFNRQRgU2orTrpFhI03nCxz/i+iVyKeQqg5FjAVVokF0/+B/8nq1VmJr0kkIJ'
    b'oPvFcT7GgJ5doFl3nO9jx2meAMFn4Epv+6sNIP5Jer2tRY6AgW3g4rqtKXvA5Q4w/GTIpuxK'
    b'QVpCoQC8n9E35YChW6BvzZtb6xynD0CGZpW6AQ4OgfEiZa/7vLu3c27/9rTm9wOdBnK4rX9f'
    b'CAAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAAOTQAADk0BRtVoCQAAAAd0SU1FB+UBEQAy'
    b'Fd81iUEAAAGnSURBVFjD7ZZPiqtAGMRLfdpgSK/9s4+4y0Wy8gLZJJCAEvAiIYsEcofcJZCF'
    b'5BoJCbTSqbeYGRcTZBxGZubx/IGr/iirS60W6Onp+d8x2g5ut1sWRQGSAICqqlBVVb1u2zZs'
    b'234RNQzEcYzlcvmh/p+2BoqiwOFwAEmQxP1+x+12q9cHgwFc14VhGDAMA0mSfC2BzWbD0+kE'
    b'rTUejwccx4EQonUCSimUZQkhBIQQiOMYi8WideKYzWZ0XZe2bRMAp9MpP/NsX+cppWQYhsyy'
    b'jK0S2O/3PJ/PUEpBKVUnMB6PsVqtWu9gvV7zeDzWCZimCcuyEEUR5vN5s06e5xyNRszznF2+'
    b'7U265vtBpRQulwuUUp1+bk26TwbKssT1ekVZlp0aaNI1f7qIfp8Bx3EwHA7hOE6nN2rSfTIg'
    b'hICUEkKITg006T5VcRRFAACtNbIs41sffLUHtNaYTCa1/odkWcYwDCml/N4mfGO327EoiroR'
    b'v/0seE+apgyCgL7v0/M8SilpWVZ9SSnpeR5932cQBEzTtFVirY/jOI6RJMmn/gd6enr+Cf4C'
    b'yeL2pJ1F1M4AAAAASUVORK5CYII=')




#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAADnnpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHja7VdbkhsrDP1nFVkCkniI5dA8qrKDu/x7oOkeu+M4M85MVT4G3CCEWhI6'
    b'ErZN++9nNz/QmIIzzkcNKQSL5pJLnEGo3ds2R7JujrPx2sL6jm/ODQZLMMu+TMdGAx80lcVf'
    b'RuiQPxQdBGVQ/m1jc4u/XfhLIetV0bIstFu2dV+XpUh4ebTWdcmHpPHuaC3cWLArPuvxHHwM'
    b'eDhK8FydDy1ERLQFP7gYHdvAEXEwQQNBLIWEYOsZyNl+WUfAUT0cFOYmJBYjy/TRgAAbzIx5'
    b'jCywMoRAe1GMaDtcgJdtBLkAwdHoCLC5Ddg5/6Y9O6q5nvX2qCuf7vLlpK55dJKXPNK2+HIP'
    b'sw3nfIF/bZC/vCCnfb61nNxp+I5vajpt2Cv8vVftve2nyy4As7AOdRxxUpDbcDQn87WAHvF4'
    b'0HH2hK4224JkrLag8jbQiRiQdnJUKVOnNudiqMBHx40jZuaCTCjgqUROXGZKuNGpA6okFQnB'
    b'UpA/Ai4PX6YrZKbdNO0VUliuBFEmKKORbO/t5iPCt733Ub1Edi8tMjvAPNIcbgzkxggxIEJ9'
    b'BdXPAB/92gauYgChn2FWHDDbbVexeXrLLZlAC+Q85v0WoFh3BaNQYNobOEMCCGwg8RTIRuZI'
    b'hEAqAMpwfRTfBgTIoyrgJDsRVAErD9N4JRJEDWVGCU0+rlkg4SVIBDZJMsByziN/olPkUPbi'
    b'nffjBvHqk89BgkN5BdSbGlRVjhJdRDnGGDWmmFXUqdegUVWT5sRJcJ17FGBMmlLKGTYzNGe8'
    b'nCGQs9l4k81tfgtb3HRLWy5In+KKL6HEoiWVXLlKxUVUQ41Va6q5UUMqNdd8Cy02bcm03JFr'
    b'Xbrrvoceu/bU84karbK99g+gRgs1nkgJnniiBm6Mhwoa14k3AzMgxo6AeBwQIKF5YGaVnOOB'
    b'3MAM30+oCs9w0g9sKg3EgKBrxL6T2cEDdm/IvYTbuPwf4cYfRc4M6F5E7g430xJwe4BaHb8B'
    b'ykRsr8IRVCuoPshkVnysvZnNlfHq/K3o7xVtba6stN6fqjOf489FUVd740rvhzNja+vtqXfm'
    b'M7y5U3TjzbB+ERu7z300PX+OT+ZhhB74xH/w0TwM5Asr8+qLdys74H9Xur3N0h5vmb+I7zR/'
    b'xMp8JOmewWLs18D/3sL41aevKVr+c2H8NmW/Ikbfir4V/QOKpOO3EP6/mv8Bv9YOtm6LFuUA'
    b'AAGFaUNDUElDQyBwcm9maWxlAAB4nH2RPUjDUBSFT1ulIhUFOxRxyFBdtCAq0lGrUIQKoVZo'
    b'1cHkpX/QpCFJcXEUXAsO/ixWHVycdXVwFQTBHxA3NydFFynxvqTQIsYLj/dx3j2H9+4D/I0K'
    b'U82uCUDVLCOdTAjZ3KoQfIUPEQwgjjGJmfqcKKbgWV/31E11F+NZ3n1/Vp+SNxngE4hnmW5Y'
    b'xBvEM5uWznmfOMxKkkJ8Tjxu0AWJH7kuu/zGueiwn2eGjUx6njhMLBQ7WO5gVjJU4mniqKJq'
    b'lO/Puqxw3uKsVmqsdU/+wlBeW1nmOq1hJLGIJYgQIKOGMiqwEKNdI8VEms4THv4hxy+SSyZX'
    b'GYwcC6hCheT4wf/g92zNwtSkmxRKAN0vtv0xAgR3gWbdtr+Pbbt5AgSegSut7a82gPgn6fW2'
    b'Fj0C+reBi+u2Ju8BlztA5EmXDMmRArT8hQLwfkbflAMGb4HeNXdurXOcPgAZmlXqBjg4BEaL'
    b'lL3u8e6ezrn929Oa3w/KSnLKc4m6gwAAD6BpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/'
    b'eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+Cjx4'
    b'OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IlhNUCBDb3JlIDQu'
    b'NC4wLUV4aXYyIj4KIDxyZGY6UkRGIHhtbG5zOnJkZj0iaHR0cDovL3d3dy53My5vcmcvMTk5'
    b'OS8wMi8yMi1yZGYtc3ludGF4LW5zIyI+CiAgPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9'
    b'IiIKICAgIHhtbG5zOmlwdGNFeHQ9Imh0dHA6Ly9pcHRjLm9yZy9zdGQvSXB0YzR4bXBFeHQv'
    b'MjAwOC0wMi0yOS8iCiAgICB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAv'
    b'MS4wL21tLyIKICAgIHhtbG5zOnN0RXZ0PSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAv'
    b'c1R5cGUvUmVzb3VyY2VFdmVudCMiCiAgICB4bWxuczpwbHVzPSJodHRwOi8vbnMudXNlcGx1'
    b'cy5vcmcvbGRmL3htcC8xLjAvIgogICAgeG1sbnM6R0lNUD0iaHR0cDovL3d3dy5naW1wLm9y'
    b'Zy94bXAvIgogICAgeG1sbnM6ZGM9Imh0dHA6Ly9wdXJsLm9yZy9kYy9lbGVtZW50cy8xLjEv'
    b'IgogICAgeG1sbnM6dGlmZj0iaHR0cDovL25zLmFkb2JlLmNvbS90aWZmLzEuMC8iCiAgICB4'
    b'bWxuczp4bXA9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC8iCiAgIHhtcE1NOkRvY3Vt'
    b'ZW50SUQ9ImdpbXA6ZG9jaWQ6Z2ltcDozZWVmZTk5Yy1hZWIyLTRkZTktOTYzOS1iZDY3Zjlm'
    b'ZTYxZjgiCiAgIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6OTgzOGI4YTQtMjU4ZC00MTJm'
    b'LTgwYjItNTZhZGMxYTM2MThiIgogICB4bXBNTTpPcmlnaW5hbERvY3VtZW50SUQ9InhtcC5k'
    b'aWQ6NmRlMzQzOTAtNjNiNi00OTQ0LWI3MDUtNmQyYjVmM2NlYTE5IgogICBHSU1QOkFQST0i'
    b'Mi4wIgogICBHSU1QOlBsYXRmb3JtPSJNYWMgT1MiCiAgIEdJTVA6VGltZVN0YW1wPSIxNjEx'
    b'NTA3NTE1ODI3NDU3IgogICBHSU1QOlZlcnNpb249IjIuMTAuMjIiCiAgIGRjOkZvcm1hdD0i'
    b'aW1hZ2UvcG5nIgogICB0aWZmOk9yaWVudGF0aW9uPSIxIgogICB4bXA6Q3JlYXRvclRvb2w9'
    b'IkdJTVAgMi4xMCI+CiAgIDxpcHRjRXh0OkxvY2F0aW9uQ3JlYXRlZD4KICAgIDxyZGY6QmFn'
    b'Lz4KICAgPC9pcHRjRXh0OkxvY2F0aW9uQ3JlYXRlZD4KICAgPGlwdGNFeHQ6TG9jYXRpb25T'
    b'aG93bj4KICAgIDxyZGY6QmFnLz4KICAgPC9pcHRjRXh0OkxvY2F0aW9uU2hvd24+CiAgIDxp'
    b'cHRjRXh0OkFydHdvcmtPck9iamVjdD4KICAgIDxyZGY6QmFnLz4KICAgPC9pcHRjRXh0OkFy'
    b'dHdvcmtPck9iamVjdD4KICAgPGlwdGNFeHQ6UmVnaXN0cnlJZD4KICAgIDxyZGY6QmFnLz4K'
    b'ICAgPC9pcHRjRXh0OlJlZ2lzdHJ5SWQ+CiAgIDx4bXBNTTpIaXN0b3J5PgogICAgPHJkZjpT'
    b'ZXE+CiAgICAgPHJkZjpsaQogICAgICBzdEV2dDphY3Rpb249InNhdmVkIgogICAgICBzdEV2'
    b'dDpjaGFuZ2VkPSIvIgogICAgICBzdEV2dDppbnN0YW5jZUlEPSJ4bXAuaWlkOmQ5ZGQ5MjMw'
    b'LWQwNTctNDEzNi1iMjRmLTU2OGJiMjZmZTc3OSIKICAgICAgc3RFdnQ6c29mdHdhcmVBZ2Vu'
    b'dD0iR2ltcCAyLjEwIChNYWMgT1MpIgogICAgICBzdEV2dDp3aGVuPSIyMDIxLTAxLTI0VDEw'
    b'OjU4OjM1LTA2OjAwIi8+CiAgICA8L3JkZjpTZXE+CiAgIDwveG1wTU06SGlzdG9yeT4KICAg'
    b'PHBsdXM6SW1hZ2VTdXBwbGllcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkltYWdlU3Vw'
    b'cGxpZXI+CiAgIDxwbHVzOkltYWdlQ3JlYXRvcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVz'
    b'OkltYWdlQ3JlYXRvcj4KICAgPHBsdXM6Q29weXJpZ2h0T3duZXI+CiAgICA8cmRmOlNlcS8+'
    b'CiAgIDwvcGx1czpDb3B5cmlnaHRPd25lcj4KICAgPHBsdXM6TGljZW5zb3I+CiAgICA8cmRm'
    b'OlNlcS8+CiAgIDwvcGx1czpMaWNlbnNvcj4KICA8L3JkZjpEZXNjcmlwdGlvbj4KIDwvcmRm'
    b'OlJERj4KPC94OnhtcG1ldGE+CiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'CiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAKPD94cGFja2V0IGVuZD0idyI/PgdeROIAAAAGYktHRAD/AP8A/6C9'
    b'p5MAAAAJcEhZcwAACxMAAAsTAQCanBgAAAAHdElNRQflARgQOiO5eHoqAAAAI3RFWHRDb21t'
    b'ZW50AFJldmVyc2UtRW5naW5lZXJlZCBieSBoYXNpadNjEEMAAABbSURBVFjD7ZU7DgAgCEPB'
    b'+99ZFwcnwQQoiX0Jm6GV8BEhhDRm7khFL+KedyU/L6mEJVZiwhJJNeFNHm5Cj4T6YDaMgZ51'
    b'uAF4D7SZghZ7ALIJW94CSNkJIeRfFkpAJ+PtcHXSAAAAAElFTkSuQmCC')

